@@ -897,7 +897,7 @@ def func_FrontFace(mesh):
 def removedup(x):
   return list(dict.fromkeys(x))
 
-def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, min_num_point_ratio=50, max_num_point_ratio=10, range_random_inc_Z=(20,30), range_random_llZ=(0,1)):
+def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, label=False, min_num_point_ratio=50, max_num_point_ratio=10, range_random_inc_Z=(20,30), range_random_llZ=(0,1)):
     mesh_pre = mesh.copy()
 
     #danh sách index face sẽ lấy random
@@ -949,7 +949,10 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max,
             mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
             colors[idx_ver] = [100,200,10,100]
 
-    mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
+    if label == True:
+        mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
+    else:
+        mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces)
 
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
@@ -965,7 +968,7 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max,
 
 
 # lặp chỗ này để tạo sẹo dài
-def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, min_num_point_ratio=200, max_num_point_ratio=20, range_random_inc_Z=(20,30), range_num_ver_c=(10,30), range_random_llZ=(0,1)):
+def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, label=False, min_num_point_ratio=200, max_num_point_ratio=20, range_random_inc_Z=(20,30), range_num_ver_c=(10,30), range_random_llZ=(0,1)):
     mesh_pre = mesh.copy()
 
     #danh sách index face sẽ lấy random
@@ -1038,7 +1041,10 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, mi
             mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
             colors[idx_ver] = [100,200,10,100]
 
-    mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
+    if label == True:
+        mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
+    else:
+        mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces)
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
 
